@@ -2,8 +2,10 @@ import os
 import time
 from datetime import timezone
 from jsoncustom import JsonCustom
-from requestsgarant import (RequestsGarant, RequestsGarantTestBaseUrl, RequestsGarantTestEndpoint,
-                             RequestsGarantTestHeaders)
+from requestsgarant import (
+    RequestsGarant, RequestsGarantTestBaseUrl, RequestsGarantTestEndpoint, RequestsGarantTestHeaders
+)
+
 
 inn_freedom = "Свободен"
 inn_busy = "Занят"
@@ -227,7 +229,7 @@ class VTBLead(VTBFather):
 
 class Open(RequestsGarantTestEndpoint):
     base_url = 'https://openpartners.ru/api/v2/request/'
-    JSON_TEST_OPEN_BASE_DIR = f'{os.path.abspath(os.curdir)}/'
+    JSON_TEST_OPEN_BASE_DIR = f'{os.path.abspath(os.curdir)}/jsons/'
     token = None
 
     def __init__(self):
@@ -303,7 +305,7 @@ class OpenScoringID(OpenLeadScoring):
         self.method = 'post'
 
     def define_json_response_test(self):
-        from .open_methods import create_json
+        from open_methods import create_json
 
         self.json_response_test = {
             'id': f'{get_rand_str(8)}-{get_rand_str(4)}-{get_rand_str(4)}-{get_rand_str(4)}-{get_rand_str(12)}'
@@ -405,24 +407,26 @@ class ModuleLead(Module):
 
 
 class Tochka(RequestsGarant):
-    def __init__(self):
+    token = None
+
+    def __init__(self, json):
         super().__init__()
         self.url = 'https://open.tochka.com:3000/rest/v1/'
+        self.json = json
+        self.json['token'] = self.token
 
 
 class TochkaStatusLead(Tochka):
     def __init__(self, json):
-        super().__init__()
+        super().__init__(json)
         self.method = 'post'
-        self.json = json
         self.url += 'request/statuses'
 
 
 class TochkaLead(Tochka):
     def __init__(self, json):
-        super().__init__()
+        super().__init__(json)
         self.method = 'post'
-        self.json = json
         self.url += 'request/new'
 
     def do_json(self):
@@ -438,9 +442,8 @@ class TochkaLead(Tochka):
 
 class TochkaRegistryUr(Tochka):
     def __init__(self, json):
-        super().__init__()
+        super().__init__(json)
         self.method = 'post'
-        self.json = json
         self.url += 'request/registration'
 
     def do_json(self):
@@ -452,11 +455,15 @@ class TochkaRegistryUr(Tochka):
 
 class TochkaAddDocs(Tochka):
     def __init__(self, json):
-        super().__init__()
+        super().__init__(json)
+        self.json['request']['zip'] = self.make_zip()
         self.method = 'post'
-        self.json = json
         self.url += 'request/add_files'
 
+    def make_zip(self):
+        from zip_functions import make_zip
+        return make_zip(self.json['request']['zip'])
+
     def do_json(self):
         if isinstance(self.response_json, dict):
             if self.response_json:
